@@ -5,8 +5,8 @@ __conectores = [' ','T']
 __separadores_fecha = ['-', '.', '/', ' ', '']
 __separadores_hora = ['-', '.', ':', ' ', '']
 
-__generadores_fecha = [lambda s:f'%Y{s}%m{s}%d', lambda s:f'%d{s}%m{s}%Y', lambda s:f'%d{s}%m{s}%y' ]
-__generadores_horas = [lambda s: f'%H{s}%M{s}%S',lambda s: f'%H{s}%M']
+__generadores_fecha = [lambda s: f'%Y{s}%m{s}%d', lambda s: f'%d{s}%m{s}%Y', lambda s: f'%d{s}%m{s}%y']
+__generadores_horas = [lambda s: f'%H{s}%M{s}%S', lambda s: f'%H{s}%M']
 
 __formatos_default_fecha = [f(s) for f in __generadores_fecha for s in __separadores_fecha]
 __formatos_default_hora = [f(s) for f in __generadores_horas for s in __separadores_hora]
@@ -90,7 +90,7 @@ def restar_mes(fecha,prevenir_futuro=False):
     if fecha.month == 1:
         return fecha.replace(year=fecha.year -1, month=12)
     else:
-        return fecha.replace(month=fecha.month -1)
+        return fecha.replace(day=1) - __dt.timedelta(days=1)
 
 def hoy():
     return __dt.datetime.today().replace(hour=0,minute=0,second=0,microsecond=0)
@@ -136,30 +136,35 @@ def obtener_periodo(fecha,formatos=__formatos_default_periodo,prevenir_futuro=Tr
 def mes_act_dia_1():
     return mes_dia_1(hoy())
 
-def mes_act_ult_dia():
-    return min(hoy(),mes_ult_dia(hoy()))
+def mes_act_ult_dia(prevenir_futuro=True):
+    if prevenir_futuro:
+        return hoy()
+    else:
+        return mes_ult_dia(hoy(),prevenir_futuro=prevenir_futuro)
 
-def mes_act_periodo():
-    return mes_periodo(mes_act_dia_1())
+def mes_act_periodo(prevenir_futuro=True):
+    return mes_periodo(mes_act_dia_1(),prevenir_futuro=prevenir_futuro)
 
 def mes_ant_dia_1():
     return restar_mes(mes_act_dia_1())
 
 def mes_ant_ult_dia():
     return mes_ult_dia(mes_ant_dia_1())
-    
+
 def mes_ant_periodo():
     return mes_periodo(mes_ant_dia_1())
 
 def sem_dia_1(fecha,offset=0,formatos=__formatos_default_fecha,prevenir_futuro=False):
-    fecha = validar_fecha(fecha=fecha,formatos=formatos,prevenir_futuro=prevenir_futuro)
-    fecha = fecha.replace(hour=0,minute=0,second=0,microsecond=0)
-    
-    dia_semana = fecha.weekday()
-    desplazamiento  = __dt.timedelta(days=(offset - dia_semana))
-    
-    return fecha + desplazamiento
+    fecha =  (validar_fecha(
+            fecha=fecha,
+            formatos=formatos,
+            prevenir_futuro=prevenir_futuro
+        )
+        .replace(hour=0, minute=0, second=0, microsecond=0)
+    )
     
+    return fecha + __dt.timedelta(days = (offset - fecha.weekday()) )
+
 def sem_act_dia_1(offset=0,formatos=__formatos_default_fecha,prevenir_futuro=False):
    return sem_dia_1(fecha=hoy(),offset=offset,formatos=formatos,prevenir_futuro=prevenir_futuro)
 
@@ -192,7 +197,7 @@ def iterar_entre_timestamps(ts_ini,ts_fin,timedelta,formatos=__formatos_default_
         yield ts_cur_ini,ts_cur_end
         
         ts_loop += td
-        
+
 def iterar_entre_timestamps_diario(ts_ini,ts_fin,formatos=__formatos_default_fecha,prevenir_futuro=False):
     '''Devuelve un iterador diario entre dos objetos datetime. 
     
@@ -238,7 +243,6 @@ def iterar_mensual(ts_ini,ts_fin,formatos=__formatos_default_fecha,prevenir_futu
 
 def lista_mensual(fecha,n,ult_dia = True):
 
-
     if ult_dia:
         
         func = lambda x: mes_ult_dia(x,prevenir_futuro=False) 
@@ -274,7 +278,7 @@ def input_fecha(nombre='',formatos=__formatos_default_fecha,prevenir_futuro=Fals
     fecha = validar_fecha(fecha,formatos=formatos,prevenir_futuro=prevenir_futuro)
     
     return fecha
-    
+
 def input_fechas(*args,formatos=__formatos_default_fecha,prevenir_futuro=False):
     '''Toma un conjunto de strings para solicitar fechas al usuario.
     Los valores deberían ser indicativos del tipo de fecha que se espera, ejemplos:
@@ -307,16 +311,21 @@ def validar_fecha(fecha,formatos=__formatos_default_fecha,prevenir_futuro=True):
     else:
         return fecha
 
-def validar_fechas(fecha_ini,fecha_fin,formatos=__formatos_default_fecha,prevenir_futuro=True):
+def validar_fechas(*args,formatos=__formatos_default_fecha,prevenir_futuro=True,ordenado=True):
     '''
     Toma dos fechas, las valida usando la función validar_fecha y las ordena de más antigua a más reciente.
     '''
-    fecha_ini = validar_fecha(fecha_ini,formatos=formatos,prevenir_futuro=prevenir_futuro)
-    fecha_fin = validar_fecha(fecha_fin,formatos=formatos,prevenir_futuro=prevenir_futuro)
     
-    fecha_ini, fecha_fin = sorted([fecha_ini,fecha_fin])
+    fechas = [validar_fecha(
+            a,
+            formatos=formatos,
+            prevenir_futuro=prevenir_futuro)
+        for a in args]
     
-    return fecha_ini, fecha_fin
+    if ordenado:
+        return sorted(fechas)
+    else:
+        return fechas
 
 def validar_fecha_hora(fecha,formatos=__formatos_default_fecha_hora,prevenir_futuro=True):
     '''Compara la fecha ingresada vs la fecha actual del sistema.
